@@ -1,5 +1,5 @@
-# $File: //member/autrijus/.vimrc $ $Author: autrijus $
-# $Revision: #14 $ $Change: 4137 $ $DateTime: 2003/02/08 11:41:59 $
+# $File: /local/member/autrijus/Win32-Exe//lib/Win32/Exe/Resource/Icon.pm $ $Author: autrijus $
+# $Revision: #10 $ $Change: 3896 $ $Date: 2004-02-17T01:28:40.619691Z $
 
 package Win32::Exe::Resource::Icon;
 
@@ -9,7 +9,7 @@ use constant FORMAT => (
     Width	    => 'C',
     Height	    => 'C',
     ColorCount	    => 'C',
-    Reserved	    => 'C',
+    _		    => 'C',
     Planes	    => 'v',
     BitCount	    => 'v',
     ImageSize	    => 'V',
